Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/m6rclib/__init__.py | (no class) | 4 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/embed_lexer.py | EmbedLexer | 21 | 0 | 0 | 6 | 0 | 100%
src/m6rclib/embed_lexer.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_ast_node.py | MetaphorASTNodeType | 0 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_ast_node.py | MetaphorASTNode | 21 | 0 | 7 | 6 | 0 | 100%
src/m6rclib/metaphor_ast_node.py | (no class) | 24 | 0 | 1 | 0 | 0 | 100%
src/m6rclib/metaphor_lexer.py | MetaphorLexer | 75 | 0 | 0 | 42 | 0 | 100%
src/m6rclib/metaphor_lexer.py | (no class) | 16 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_parser.py | MetaphorParserFileAlreadyUsedError | 3 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_parser.py | MetaphorParserSyntaxError | 6 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_parser.py | MetaphorParserError | 2 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_parser.py | MetaphorParser | 174 | 0 | 0 | 92 | 0 | 100%
src/m6rclib/metaphor_parser.py | (no class) | 31 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_token.py | TokenType | 0 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_token.py | Token | 1 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/metaphor_token.py | (no class) | 26 | 0 | 0 | 2 | 0 | 100%
Total |  | 412 | 0 | 8 | 148 | 0 | 100%

No items found using the specified filter.